@@ -2,7 +2,7 @@ package Finance::Budget;
 
 use strict;
 use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 {   use Carp;
     use Text::CSV;
     use Date::Manip;
@@ -284,13 +284,17 @@ sub _build_transactions {
         return $default;
     };
 
+    my $type_help
+        = "transaction_types must have { category, amount, recurrence }";
+
     my $major_payment_hit = 0;
 
     for my $type_hr (@{ $self->{transaction_types} })
     {
-        my $category   = $type_hr->{category};
+        my $category   = $type_hr->{category} || die "$type_help\n";
+        my $amount     = $type_hr->{amount} // die "$type_help\n";
+        my $recurrence = $type_hr->{recurrence} || die "$type_help\n";
         my $base_date  = $type_hr->{base_date};
-        my $recurrence = $type_hr->{recurrence};
 
         $width = $width < length $category ? length $category : $width;
 
@@ -304,10 +308,10 @@ sub _build_transactions {
         {
             my $epoch = $date->printf('%s');
 
-            my $amount = $find_amount_cr->(
+            $amount = $find_amount_cr->(
                 $type_hr->{category},
-                $epoch, 
-                $type_hr->{amount},
+                $epoch,
+                $amount,
             );
 
             $events_for{$epoch} //= [];
@@ -549,25 +553,25 @@ budget.
       {   days              => 365,
           opening_balance   => 123.01,
           transaction_types => [
-              {   category => 'PAYCHECK',
-                  amount   => 1234.56,
-                  event    => '0:0:2*4:0:0:0', # every second Thursday
+              {   category   => 'PAYCHECK',
+                  amount     => 1234.56,
+                  recurrence => '0:0:2*4:0:0:0', # every second Thursday
               },
-              {   category => 'Visa',
-                  amount   => -100.00,
-                  event    => '0:1*0:0:0:0:0', # first of every month
+              {   category   => 'Visa',
+                  amount     => -100.00,
+                  recurrence => '0:1*0:0:0:0:0', # first of every month
               },
-              {   category => 'Cox',
-                  amount   => -101.01,
-                  event    => '0:1*0:15:0:0:0', # fifteenth of every month
+              {   category   => 'Cox',
+                  amount     => -101.01,
+                  recurrence => '0:1*0:15:0:0:0', # fifteenth of every month
               },
-              {   category => 'Mortgage',
-                  amount   => -1000.10,
-                  event    => '0:1*0:0:0:0:0',
+              {   category   => 'Mortgage',
+                  amount     => -1000.10,
+                  recurrence => '0:1*0:0:0:0:0',
               },
-              {   category => 'Water',
-                  amount   => -150.00,
-                  event    => '0:3*0:1:0:0:0', # first of every third month
+              {   category   => 'Water',
+                  amount     => -150.00,
+                  recurrence => '0:3*0:1:0:0:0', # first of every third month
               },
           ],
           exceptions => [
@@ -607,7 +611,7 @@ budget.
                   qr{ us \s bank \s mtg }xmsi
               ],
               'Water' => [
-                  qr{ waters \s are \s us }xmsi
+                  qr{ waters \s r \s us }xmsi
               ]
           }
       }
@@ -658,7 +662,7 @@ The number of days to project into the future. The default is 365.
 
 =item date_format
 
-The format that the transactions will use on stringafication. 
+The format that the transactions will use on stringafication.
 The default is '%m/%d/%Y'.
 
 =item currency_symbol
